"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Formbricks = void 0;
const GenericFunctions_1 = require("./GenericFunctions");
class Formbricks {
    constructor() {
        this.description = {
            displayName: "Formbricks",
            name: "formbricks",
            icon: "file:formbricks.svg",
            group: ["trigger"],
            version: 1,
            subtitle: '=Surveys: {{$parameter["surveyIds"]}}',
            description: "Open Source Surveys & Experience Management Solution",
            defaults: {
                name: "Formbricks",
            },
            inputs: [],
            outputs: ["main"],
            credentials: [
                {
                    name: "formbricksApi",
                    required: true,
                },
            ],
            webhooks: [
                {
                    name: "default",
                    httpMethod: "POST",
                    responseMode: "onReceived",
                    path: "webhook",
                },
            ],
            properties: [
                {
                    displayName: "Events",
                    name: "events",
                    type: "multiOptions",
                    options: [
                        {
                            name: "Response Created",
                            value: "responseCreated",
                            description: "Triggers when a new response is created for a survey. Normally triggered after the first question was answered.",
                        },
                        {
                            name: "Response Updated",
                            value: "responseUpdated",
                            description: "Triggers when a response is updated within a survey",
                        },
                        {
                            name: "Response Finished",
                            value: "responseFinished",
                            description: "Triggers when a response is marked as finished",
                        },
                    ],
                    default: [],
                    required: true,
                },
                {
                    displayName: "Survey",
                    name: "surveyIds",
                    description: 'Survey which should trigger workflow. Only trigger this node for a specific survey within the environment. Choose from the list, or specify an ID using an <a href="https://docs.n8n.io/code-examples/expressions/">expression</a>.',
                    type: "multiOptions",
                    typeOptions: {
                        loadOptionsMethod: "getSurveys",
                    },
                    options: [],
                    default: [],
                    required: true,
                },
            ],
        };
        this.methods = {
            loadOptions: {
                getSurveys: GenericFunctions_1.getSurveys,
            },
        };
        this.webhookMethods = {
            default: {
                async checkExists() {
                    const webhookData = this.getWorkflowStaticData("node");
                    const webhookUrl = this.getNodeWebhookUrl("default");
                    const surveyIds = this.getNodeParameter("surveyIds");
                    const endpoint = "/webhooks";
                    try {
                        const response = await GenericFunctions_1.apiRequest.call(this, "GET", endpoint, {});
                        for (const webhook of response.data) {
                            for (const surveyId of webhook.surveyIds) {
                                if (surveyIds.includes(surveyId) && webhook.url === webhookUrl) {
                                    webhookData.webhookId = webhook.id;
                                    return true;
                                }
                            }
                        }
                    }
                    catch (error) {
                        return false;
                    }
                    return false;
                },
                async create() {
                    const webhookData = this.getWorkflowStaticData("node");
                    const webhookUrl = this.getNodeWebhookUrl("default");
                    const surveyIds = this.getNodeParameter("surveyIds");
                    const events = this.getNodeParameter("events");
                    const body = {
                        url: webhookUrl,
                        triggers: events,
                        surveyIds: surveyIds,
                        source: "n8n",
                    };
                    const endpoint = "/webhooks";
                    try {
                        const response = await GenericFunctions_1.apiRequest.call(this, "POST", endpoint, body);
                        webhookData.webhookId = response.data.id;
                        return true;
                    }
                    catch (error) {
                        return false;
                    }
                },
                async delete() {
                    const webhookData = this.getWorkflowStaticData("node");
                    if (webhookData.webhookId !== undefined) {
                        const endpoint = `/webhooks/${webhookData.webhookId}`;
                        try {
                            await GenericFunctions_1.apiRequest.call(this, "DELETE", endpoint, {});
                        }
                        catch (error) {
                            return false;
                        }
                        delete webhookData.webhookId;
                    }
                    return false;
                },
            },
        };
    }
    async webhook() {
        const bodyData = this.getBodyData();
        return {
            workflowData: [this.helpers.returnJsonArray(bodyData)],
        };
    }
}
exports.Formbricks = Formbricks;
//# sourceMappingURL=Formbricks.node.js.map